package com.persagy.dc.define.controller;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dc.basic.model.QueryCriteria;
import com.persagy.dc.basic.utils.DigitalCommonUtils;
import com.persagy.dc.common.constant.ResponseCode;
import com.persagy.dc.common.exception.BusinessException;
import com.persagy.dc.common.model.response.CommonResult;
import com.persagy.dc.common.model.response.PageList;
import com.persagy.dc.common.utils.ResultHelper;
import com.persagy.dc.define.entity.ObjectInfoDefine;
import com.persagy.dc.define.service.IObjectInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * 对象类型 Controller
 * @author Charlie Yu
 * @date 2021-06-25
 */
@RestController
@RequestMapping("/define/info")
public class ObjectInfoController {

    @Autowired
    private IObjectInfoService service;

    @PostMapping("query")
    public CommonResult<PageList<ObjectInfoDefine>> query(@RequestBody QueryCriteria criteria) {
        if(criteria == null) {
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        QueryWrapper<ObjectInfoDefine> wrapper = new QueryWrapper<>();
        // 添加所属项目条件
        DigitalCommonUtils.ensureProjectCriteria(wrapper);
        // 转换查询条件
        criteria.toWrapper(wrapper);
        Page page = criteria.toPage();
        // 没有排序条件时，按默认条件排序
        if(CollUtil.isEmpty(page.getOrders())) {
            wrapper.orderByAsc("show_order");
        }
        page = service.queryByCondition(criteria.toPage(), wrapper);
        return ResultHelper.multi(page.getRecords(), page.getTotal());
    }

    @PostMapping("/create")
    public CommonResult<ObjectInfoDefine> create(@Valid @RequestBody ObjectInfoDefine vo){
        List<ObjectInfoDefine> voList = CollUtil.newArrayList(vo);
        service.insert(voList);
        return ResultHelper.single(vo);
    }

    @PostMapping("/createBatch")
    public CommonResult<PageList<ObjectInfoDefine>> createBatch(@Valid @RequestBody List<ObjectInfoDefine> voList){
        voList = service.insert(voList);
        return ResultHelper.multi(voList);
    }

    @PostMapping("/update")
    public CommonResult<ObjectInfoDefine> update(@Valid @RequestBody ObjectInfoDefine vo){
        List<ObjectInfoDefine> voList = CollUtil.newArrayList(vo);
        service.update(voList);
        return ResultHelper.single(vo);
    }

    @PostMapping("/updateBatch")
    public CommonResult<PageList<ObjectInfoDefine>> updateBatch(@Valid @RequestBody List<ObjectInfoDefine> voList){
        voList = service.update(voList);
        return ResultHelper.multi(voList);
    }

    @PostMapping("/delete")
    public CommonResult delete(@RequestBody String id){
        service.delete(CollUtil.newArrayList(id));
        return ResultHelper.success();
    }

    @PostMapping("/deleteBatch")
    public CommonResult deleteBatch(@RequestBody List<String> id){
        service.delete(id);
        return ResultHelper.success();
    }
}
